//
//  CDTransmitImporter.m
//  Tester
//
//  Created by alto on 9/7/10.
//  Copyright 2010 FuelCollective. All rights reserved.
//

#import "CDTransmitImporter.h"


@implementation CDTransmitImportFavorite

@synthesize nickname, username, password, protocol, server, initialPath;
@synthesize port;
@synthesize passwordInKeychain;

-(void)dealloc{
	[nickname release];
	[username release];
	[password release];
	[protocol release];
	[server release];
	[initialPath release];
	
	[super dealloc];
}

-(id)initWithCoder:(NSKeyedUnarchiver*)unarchiver{
	self = [self init];
	
	//There are more attributes, but the rest is Transmit-bound
	
	passwordInKeychain = [unarchiver decodeBoolForKey:@"identityInKeychain"];
	nickname = [[unarchiver decodeObjectForKey:@"nickname"] retain];
	initialPath = [[unarchiver decodeObjectForKey:@"initialRemotePath"] retain];
	password = [[unarchiver decodeObjectForKey:@"password"] retain];
	port = [unarchiver decodeIntForKey:@"port"];
	protocol = [[unarchiver decodeObjectForKey:@"protocol"] retain];
	server = [[unarchiver decodeObjectForKey:@"server"] retain];
	username = [[unarchiver decodeObjectForKey:@"username"] retain];
	
	return self;
}

@end


@interface CDTransmitImportFavoriteCollection : NSObject {
	NSString *_name;
	NSArray *_favorites;
}

@property (readonly) NSArray *favorites; //The root favorite collection has favorite collections here, the rest has favorites themselves here
@property (readonly) NSString *name; //Name of the collection

@end
@implementation CDTransmitImportFavoriteCollection

@synthesize name = _name;
@synthesize favorites = _favorites ;

-(void)dealloc{
	[_name release];
	[_favorites release];
	[super dealloc];
}
-(id)initWithCoder:(NSKeyedUnarchiver*)unarchiver{
	self = [self init];
	
	_name = [[unarchiver decodeObjectForKey:@"name"] retain];
	_favorites = [[unarchiver decodeObjectForKey:@"contents"] retain];
	
	//NSLog(@"%@", [unarchiver _blobForCurrentObject]); -- the private method used for reverse engineering
	
	return self;
}
@end



@implementation CDTransmitImporter
+(NSArray*)favoritesFromPreferences{
	NSString *path = [@"~/Library/Preferences/com.panic.Transmit.plist" stringByExpandingTildeInPath]; //Path to the prefs
	NSDictionary *prefDict = [NSDictionary dictionaryWithContentsOfFile:path];
	
	NSData *collectionsData = [prefDict objectForKey:@"FavoriteCollections"]; //Data
	
	//Transmit's classes have generic names - avoiding conflict
	[NSKeyedUnarchiver setClass:[CDTransmitImportFavoriteCollection class] forClassName:@"FavoriteCollection"];
	[NSKeyedUnarchiver setClass:[CDTransmitImportFavoriteCollection class] forClassName:@"HistoryCollection"];
	[NSKeyedUnarchiver setClass:[CDTransmitImportFavorite class] forClassName:@"Favorite"];
	
	CDTransmitImportFavoriteCollection *rootCollection = [NSKeyedUnarchiver unarchiveObjectWithData:collectionsData];
	
	NSArray *collections = [rootCollection favorites]; //The root has collections
	NSMutableArray *favorites = [NSMutableArray array];
	for (CDTransmitImportFavoriteCollection *aCol in collections){
		if ([[aCol name] isEqualToString:@"History"]){
			continue; //Don't import history
		}
		[favorites addObjectsFromArray:[aCol favorites]];
	}
	
	return favorites;
}
@end
